@@ -2,10 +2,10 @@ import logging
 
 from paste.deploy.converters import asbool, aslist
 
-from pylons import request, response
+from pylons import request, response, url
 from pylons import tmpl_context as c
 from pylons.controllers import WSGIController
-from pylons.controllers.util import abort, redirect_to
+from pylons.controllers.util import abort, redirect
 from pylons.decorators import jsonify
 from pylons.templating import render_mako as render
 
@@ -245,13 +245,13 @@ class Controller(WSGIController):
         if params:
             for key in params:
                 redirect_params[key] = params[key]
-        redirect_to(
+        redirect(url(
             controller=self.controller, action='show', id=member.id,
-            format=self.format, **redirect_params)
+            format=self.format, **redirect_params))
 
     def _redirect_to_collection(self):
-        redirect_to(
-            controller=self.controller, action='index', format=self.format)
+        redirect(url(
+            controller=self.controller, action='index', format=self.format))
 
     def _render(self, *args, **kwargs):
         format = kwargs.get('format', self.format)
@@ -320,20 +320,22 @@ class Controller(WSGIController):
         """
         if self.collection is not None:
             log.debug('Rendering collection')
-            obj = self.entity.to_simple_collection(self.collection, self.fields)
-            for member, simple_member in zip(self.collection, obj):
-                simple_member['__path__'] = self.get_member_path(member)
-            result_count = len(obj)
+            items = self.collection
         elif self.member is not None:
             log.debug('Rendering member')
-            obj = self.member.to_simple_object(self.fields)
-            obj['__path__'] = self.get_member_path(self.member)
-            obj = [obj]
-            result_count = 1
+            items = [self.member]
         else:
             log.debug('Neither collection nor member was set.')
+            items = None
             obj = None
             result_count = 0
+
+        if items is not None:
+            obj = self.entity.to_simple_collection(items, self.fields)
+            for member, simple_member in zip(items, obj):
+                simple_member['__path__'] = self.get_member_path(member)
+            result_count = len(obj)
+
         # Wrap ``obj`` (usually)
         if wrap:
             obj = dict(
